@@ -11,4 +11,4 @@ to stub files/frozen modules and their usage in MicropyCli
 from . import source
 from .stubs import StubManager
 
-__all__ = ['StubManager', 'source']
+__all__ = ["StubManager", "source"]
